==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/GlobalValidationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.GlobalValidationArgs.builder
import com.pulumi.azurenative.app.kotlin.enums.UnauthenticatedClientActionV2
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings that determines the validation flow of users using ContainerApp Service Authentication/Authorization.
 * @property excludedPaths The paths for which unauthenticated flow would not be redirected to the login page.
 * @property redirectToProvider The default authentication provider to use when multiple providers are configured.
 * This setting is only needed if multiple providers are configured and the unauthenticated client
 * action is set to "RedirectToLoginPage".
 * @property unauthenticatedClientAction The action to take when an unauthenticated client attempts to access the app.
 */
public data class GlobalValidationArgs(
    public val excludedPaths: Output<List<String>>? = null,
    public val redirectToProvider: Output<String>? = null,
    public val unauthenticatedClientAction: Output<UnauthenticatedClientActionV2>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.GlobalValidationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.GlobalValidationArgs =
        com.pulumi.azurenative.app.inputs.GlobalValidationArgs.builder()
            .excludedPaths(excludedPaths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .redirectToProvider(redirectToProvider?.applyValue({ args0 -> args0 }))
            .unauthenticatedClientAction(
                unauthenticatedClientAction?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GlobalValidationArgs].
 */
@PulumiTagMarker
public class GlobalValidationArgsBuilder internal constructor() {
    private var excludedPaths: Output<List<String>>? = null

    private var redirectToProvider: Output<String>? = null

    private var unauthenticatedClientAction: Output<UnauthenticatedClientActionV2>? = null

    /**
     * @param value The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("liikqcpcwkfxxcqe")
    public suspend fun excludedPaths(`value`: Output<List<String>>) {
        this.excludedPaths = value
    }

    @JvmName("bngmbuxppcakwhgy")
    public suspend fun excludedPaths(vararg values: Output<String>) {
        this.excludedPaths = Output.all(values.asList())
    }

    /**
     * @param values The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("fafowixlpceregia")
    public suspend fun excludedPaths(values: List<Output<String>>) {
        this.excludedPaths = Output.all(values)
    }

    /**
     * @param value The default authentication provider to use when multiple providers are configured.
     * This setting is only needed if multiple providers are configured and the unauthenticated client
     * action is set to "RedirectToLoginPage".
     */
    @JvmName("msgapkyxgccxraas")
    public suspend fun redirectToProvider(`value`: Output<String>) {
        this.redirectToProvider = value
    }

    /**
     * @param value The action to take when an unauthenticated client attempts to access the app.
     */
    @JvmName("xhdlrajnycjqltjr")
    public suspend fun unauthenticatedClientAction(`value`: Output<UnauthenticatedClientActionV2>) {
        this.unauthenticatedClientAction = value
    }

    /**
     * @param value The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("mawcqpkhoojuxbdx")
    public suspend fun excludedPaths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedPaths = mapped
    }

    /**
     * @param values The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("tqtwqybtciwcasix")
    public suspend fun excludedPaths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedPaths = mapped
    }

    /**
     * @param value The default authentication provider to use when multiple providers are configured.
     * This setting is only needed if multiple providers are configured and the unauthenticated client
     * action is set to "RedirectToLoginPage".
     */
    @JvmName("grnniknxritkaqox")
    public suspend fun redirectToProvider(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.redirectToProvider = mapped
    }

    /**
     * @param value The action to take when an unauthenticated client attempts to access the app.
     */
    @JvmName("knxkhuqdpjunfwgy")
    public suspend fun unauthenticatedClientAction(`value`: UnauthenticatedClientActionV2?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unauthenticatedClientAction = mapped
    }

    internal fun build(): GlobalValidationArgs = GlobalValidationArgs(
        excludedPaths = excludedPaths,
        redirectToProvider = redirectToProvider,
        unauthenticatedClientAction = unauthenticatedClientAction,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/GlobalValidationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.GlobalValidationArgs.builder
import com.pulumi.azurenative.app.kotlin.enums.UnauthenticatedClientActionV2
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings that determines the validation flow of users using ContainerApp Service Authentication/Authorization.
 * @property excludedPaths The paths for which unauthenticated flow would not be redirected to the login page.
 * @property redirectToProvider The default authentication provider to use when multiple providers are configured.
 * This setting is only needed if multiple providers are configured and the unauthenticated client
 * action is set to "RedirectToLoginPage".
 * @property unauthenticatedClientAction The action to take when an unauthenticated client attempts to access the app.
 */
public data class GlobalValidationArgs(
    public val excludedPaths: Output<List<String>>? = null,
    public val redirectToProvider: Output<String>? = null,
    public val unauthenticatedClientAction: Output<UnauthenticatedClientActionV2>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.GlobalValidationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.GlobalValidationArgs =
        com.pulumi.azurenative.app.inputs.GlobalValidationArgs.builder()
            .excludedPaths(excludedPaths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .redirectToProvider(redirectToProvider?.applyValue({ args0 -> args0 }))
            .unauthenticatedClientAction(
                unauthenticatedClientAction?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GlobalValidationArgs].
 */
@PulumiTagMarker
public class GlobalValidationArgsBuilder internal constructor() {
    private var excludedPaths: Output<List<String>>? = null

    private var redirectToProvider: Output<String>? = null

    private var unauthenticatedClientAction: Output<UnauthenticatedClientActionV2>? = null

    /**
     * @param value The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("weyytdyaketlnwbo")
    public suspend fun excludedPaths(`value`: Output<List<String>>) {
        this.excludedPaths = value
    }

    @JvmName("kferwngfyeomgask")
    public suspend fun excludedPaths(vararg values: Output<String>) {
        this.excludedPaths = Output.all(values.asList())
    }

    /**
     * @param values The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("naqfdnwgdtgimlnj")
    public suspend fun excludedPaths(values: List<Output<String>>) {
        this.excludedPaths = Output.all(values)
    }

    /**
     * @param value The default authentication provider to use when multiple providers are configured.
     * This setting is only needed if multiple providers are configured and the unauthenticated client
     * action is set to "RedirectToLoginPage".
     */
    @JvmName("lbdoxdoxbfljnrqy")
    public suspend fun redirectToProvider(`value`: Output<String>) {
        this.redirectToProvider = value
    }

    /**
     * @param value The action to take when an unauthenticated client attempts to access the app.
     */
    @JvmName("kaavincweiylvrne")
    public suspend fun unauthenticatedClientAction(`value`: Output<UnauthenticatedClientActionV2>) {
        this.unauthenticatedClientAction = value
    }

    /**
     * @param value The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("gpsnjolwxorkutxs")
    public suspend fun excludedPaths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedPaths = mapped
    }

    /**
     * @param values The paths for which unauthenticated flow would not be redirected to the login page.
     */
    @JvmName("xbqrtgltbbjybium")
    public suspend fun excludedPaths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedPaths = mapped
    }

    /**
     * @param value The default authentication provider to use when multiple providers are configured.
     * This setting is only needed if multiple providers are configured and the unauthenticated client
     * action is set to "RedirectToLoginPage".
     */
    @JvmName("woiunpfdkrohvxaw")
    public suspend fun redirectToProvider(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.redirectToProvider = mapped
    }

    /**
     * @param value The action to take when an unauthenticated client attempts to access the app.
     */
    @JvmName("cbircomleenjmnip")
    public suspend fun unauthenticatedClientAction(`value`: UnauthenticatedClientActionV2?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unauthenticatedClientAction = mapped
    }

    internal fun build(): GlobalValidationArgs = GlobalValidationArgs(
        excludedPaths = excludedPaths,
        redirectToProvider = redirectToProvider,
        unauthenticatedClientAction = unauthenticatedClientAction,
    )
}
